pub struct VPKHeaderV2 {
pub embed_chunk_length: u32,
pub chunk_hashes_length: u32,
pub self_hashes_length: u32,
pub signature_length: u32,
}Fields
embed_chunk_length: u32chunk_hashes_length: u32self_hashes_length: u32signature_length: u32Trait Implementations
Sourceimpl BinRead for VPKHeaderV2
impl BinRead for VPKHeaderV2
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreAuto Trait Implementations
impl Freeze for VPKHeaderV2
impl RefUnwindSafe for VPKHeaderV2
impl Send for VPKHeaderV2
impl Sync for VPKHeaderV2
impl Unpin for VPKHeaderV2
impl UnsafeUnpin for VPKHeaderV2
impl UnwindSafe for VPKHeaderV2